searchNodes=[{"doc":"Functions for basic astronomical observations such as sunrise, sunset, solstice, equinox, moonrise, moonset and moon phase.","ref":"Astro.html","title":"Astro","type":"module"},{"doc":"Returns the date time of a given lunar phase at or after a given date time or date. Arguments date_time is a DateTime or a Date or any struct that meets the requirements of t:Calendar.date or t:Calendar.datetime phase is the required lunar phase expressed as a float number of degrees between 0.0 and 360.0 Returns {:ok, date_time} at which the phase occurs or {:error, {module, reason}} Example iex&gt; Astro . date_time_lunar_phase_at_or_after ( ~D[2021-08-01] , Astro.Lunar . full_moon ( ) ) { :ok , ~U[2021-08-22 12:01:02.000000Z] }","ref":"Astro.html#date_time_lunar_phase_at_or_after/2","title":"Astro.date_time_lunar_phase_at_or_after/2","type":"function"},{"doc":"Returns the date time of a given lunar phase at or before a given date time or date. Arguments date_time is a DateTime or a Date or any struct that meets the requirements of t:Calendar.date or t:Calendar.datetime phase is the required lunar phase expressed as a float number of degrees between 0 and 3660 Returns {:ok, date_time} at which the phase occurs or {:error, {module, reason}} Example iex&gt; Astro . date_time_lunar_phase_at_or_before ( ~D[2021-08-01] , Astro.Lunar . new_moon ( ) ) { :ok , ~U[2021-07-10 01:15:33.000000Z] }","ref":"Astro.html#date_time_lunar_phase_at_or_before/2","title":"Astro.date_time_lunar_phase_at_or_before/2","type":"function"},{"doc":"Returns the date time of the new moon at or after a given date or date time. Arguments date_time is a DateTime or a Date or any struct that meets the requirements of t:Calendar.date or t:Calendar.datetime Returns {:ok, date_time} at which the new moon occurs or {:error, {module, reason}} Example iex&gt; Astro . date_time_new_moon_at_or_after ~D[2021-08-23] { :ok , ~U[2021-09-07 00:50:43.000000Z] }","ref":"Astro.html#date_time_new_moon_at_or_after/1","title":"Astro.date_time_new_moon_at_or_after/1","type":"function"},{"doc":"Returns the date time of the new moon before a given date or date time. Arguments date_time is a DateTime or a Date or any struct that meets the requirements of t:Calendar.date or t:Calendar.datetime Returns {:ok, date_time} at which the new moon occurs or {:error, {module, reason}} Example iex&gt; Astro . date_time_new_moon_before ~D[2021-08-23] { :ok , ~U[2021-08-08 13:49:07.000000Z] }","ref":"Astro.html#date_time_new_moon_before/1","title":"Astro.date_time_new_moon_before/1","type":"function"},{"doc":"beta and lambda in degrees","ref":"Astro.html#declination/3","title":"Astro.declination/3","type":"function"},{"doc":"Returns the datetime in UTC for either the March or September equinox. Arguments year is the gregorian year for which the equinox is to be calculated event is either :march or :september indicating which of the two annual equinox datetimes is required Returns {:ok, datetime} representing the UTC datetime of the equinox Examples iex&gt; Astro . equinox 2019 , :march { :ok , ~U[2019-03-20 21:58:06Z] } iex&gt; Astro . equinox 2019 , :september { :ok , ~U[2019-09-23 07:49:30Z] } Notes This equinox calculation is expected to be accurate to within 2 minutes for the years 1000 CE to 3000 CE. An equinox is commonly regarded as the instant of time when the plane of Earth's equator passes through the center of the Sun. This occurs twice each year: around 20 March and 23 September. In other words, it is the moment at which the center of the visible Sun is directly above the equator.","ref":"Astro.html#equinox/2","title":"Astro.equinox/2","type":"function"},{"doc":"Returns the number of hours of daylight for a given location on a given date. Arguments location is the latitude, longitude and optionally elevation for the desired hours of daylight. It can be expressed as: {lng, lat} - a tuple with longitude and latitude as floating point numbers. Note the order of the arguments. a Geo.Point.t struct to represent a location without elevation a Geo.PointZ.t struct to represent a location and elevation date is any date in the Gregorian calendar (for example, Calendar.ISO ) Returns {:ok, time} where time is a Time.t() Examples iex&gt; Astro . hours_of_daylight { 151.20666584 , - 33.8559799094 } , ~D[2019-12-07] { :ok , ~T[14:18:45] } # No sunset in summer iex&gt; Astro . hours_of_daylight { - 62.3481 , 82.5018 } , ~D[2019-06-07] { :ok , ~T[23:59:59] } # No sunrise in winter iex&gt; Astro . hours_of_daylight { - 62.3481 , 82.5018 } , ~D[2019-12-07] { :ok , ~T[00:00:00] } Notes In latitudes above the polar circles (approximately +/- 66.5631 degrees) there will be no hours of daylight in winter and 24 hours of daylight in summer.","ref":"Astro.html#hours_of_daylight/2","title":"Astro.hours_of_daylight/2","type":"function"},{"doc":"Returns the illumination of the moon as a fraction for a given date or date time. Arguments date_time is a DateTime or a Date or any struct that meets the requirements of t:Calendar.date or t:Calendar.datetime Returns a float value between 0.0 and 1.0 representing the fractional illumination of the moon. Example iex&gt; Astro . illuminated_fraction_of_moon_at ( ~D[2017-03-16] ) 0.8884442367681415 iex&gt; Astro . illuminated_fraction_of_moon_at ( ~D[1992-04-12] ) 0.6786428237168787 iex&gt; Astro . illuminated_fraction_of_moon_at ( ~U[2017-03-16 19:55:11.0Z] ) 0.8334019164562495","ref":"Astro.html#illuminated_fraction_of_moon_at/1","title":"Astro.illuminated_fraction_of_moon_at/1","type":"function"},{"doc":"Returns the lunar phase as a float number of degrees at a given date or date time. Arguments date_time is a DateTime , Date or a moment which is a float number of days since 0000-01-01 Returns the lunar phase as a float number of degrees. Example iex&gt; Astro . lunar_phase_at ~U[2021-08-22 12:01:02.170362Z] 180.00001498208536 iex&gt; Astro . lunar_phase_at ( ~U[2021-07-10 01:18:25.422335Z] ) 0.021567106773019873","ref":"Astro.html#lunar_phase_at/1","title":"Astro.lunar_phase_at/1","type":"function"},{"doc":"Returns a t:Geo.PointZ containing the right ascension and declination of the moon at a given date or date time. Arguments date_time is a DateTime or a Date or any struct that meets the requirements of t:Calendar.date or t:Calendar.datetime Returns a t:Geo.PointZ struct with coordinates {right_ascension, declination, distance} with properties %{reference: :celestial, object: :moon} distance is in meters. Example iex&gt; Astro . moon_position_at ( ~D[1992-04-12] ) % Geo.PointZ { coordinates : { 134.6978882151538 , 13.765242742787006 , 5.511320224169038e19 } , properties : %{ object : :moon , reference : :celestial } , srid : nil }","ref":"Astro.html#moon_position_at/1","title":"Astro.moon_position_at/1","type":"function"},{"doc":"beta and lambda in degrees","ref":"Astro.html#right_ascension/3","title":"Astro.right_ascension/3","type":"function"},{"doc":"Returns solar noon for a given date and location as a UTC datetime Arguments location is the latitude, longitude and optionally elevation for the desired solar noon time. It can be expressed as: {lng, lat} - a tuple with longitude and latitude as floating point numbers. Note the order of the arguments. a Geo.Point.t struct to represent a location without elevation a Geo.PointZ.t struct to represent a location and elevation date is any date in the Gregorian calendar (for example, Calendar.ISO ) Returns a UTC datetime representing solar noon at the given location for the given date Example iex&gt; Astro . solar_noon { 151.20666584 , - 33.8559799094 } , ~D[2019-12-06] { :ok , ~U[2019-12-06 01:45:42Z] } Notes Solar noon is the moment when the Sun passes a location's meridian and reaches its highest position in the sky. In most cases, it doesn't happen at 12 o'clock. At solar noon, the Sun reaches its highest position in the sky as it passes the local meridian.","ref":"Astro.html#solar_noon/2","title":"Astro.solar_noon/2","type":"function"},{"doc":"Returns the datetime in UTC for either the June or December solstice. Arguments year is the gregorian year for which the solstice is to be calculated event is either :june or :december indicating which of the two annual solstice datetimes is required Returns {:ok, datetime} representing the UTC datetime of the solstice Examples iex&gt; Astro . solstice 2019 , :december { :ok , ~U[2019-12-22 04:18:57Z] } iex&gt; Astro . solstice 2019 , :june { :ok , ~U[2019-06-21 15:53:45Z] } Notes This solstice calculation is expected to be accurate to within 2 minutes for the years 1000 CE to 3000 CE. A solstice is an event occurring when the Sun appears to reach its most northerly or southerly excursion relative to the celestial equator on the celestial sphere. Two solstices occur annually, around June 21 and December 21. The seasons of the year are determined by reference to both the solstices and the equinoxes. The term solstice can also be used in a broader sense, as the day when this occurs. The day of a solstice in either hemisphere has either the most sunlight of the year (summer solstice) or the least sunlight of the year (winter solstice) for any place other than the Equator. Alternative terms, with no ambiguity as to which hemisphere is the context, are &quot;June solstice&quot; and &quot;December solstice&quot;, referring to the months in which they take place every year.","ref":"Astro.html#solstice/2","title":"Astro.solstice/2","type":"function"},{"doc":"Returns solar longitude for a given date. Solar longitude is used to identify the seasons. Arguments date is any date in the Gregorian calendar (for example, Calendar.ISO ) Returns a float number of degrees between 0 and 360 representing the solar longitude on date Examples iex&gt; Astro . sun_apparent_longitude ~D[2019-03-21] 0.08035853207991295 iex&gt; Astro . sun_apparent_longitude ~D[2019-06-22] 90.32130455695378 iex&gt; Astro . sun_apparent_longitude ~D[2019-09-23] 179.68691978440197 iex&gt; Astro . sun_apparent_longitude ~D[2019-12-23] 270.83941087483504 Notes Solar longitude (the ecliptic longitude of the sun) in effect describes the position of the earth in its orbit, being zero at the moment of the vernal equinox. Since it is based on how far the earth has moved in its orbit since the equinox, it is a measure of what time of the tropical year (the year of seasons) we are in, but without the inaccuracies of a calendar date, which is perturbed by leap years and calendar imperfections.","ref":"Astro.html#sun_apparent_longitude/1","title":"Astro.sun_apparent_longitude/1","type":"function"},{"doc":"Returns a t:Geo.PointZ containing the right ascension and declination of the moon at a given date or date time. Arguments date_time is a DateTime or a Date or any struct that meets the requirements of t:Calendar.date or t:Calendar.datetime Returns a t:Geo.PointZ struct with coordinates {right_ascension, declination, distance} with properties %{reference: :celestial, object: :sun} . distance is in meters. Example iex&gt; Astro . sun_position_at ( ~D[1992-10-13] ) % Geo.PointZ { coordinates : { - 161.6185428539835 , - 7.785325031528879 , 149169604711.3518 } , properties : %{ object : :sun , reference : :celestial } , srid : nil }","ref":"Astro.html#sun_position_at/1","title":"Astro.sun_position_at/1","type":"function"},{"doc":"Calculates the sunrise for a given location and date. Sunrise is the moment when the upper limb of the sun appears on the horizon in the morning. Arguments location is the latitude, longitude and optionally elevation for the desired sunrise time. It can be expressed as: {lng, lat} - a tuple with longitude and latitude as floating point numbers. Note the order of the arguments. a Geo.Point.t struct to represent a location without elevation a Geo.PointZ.t struct to represent a location and elevation date is a t:Date , t:NaiveDateTime or t:DateTime to indicate the date of the year in which the sunrise time is required. options is a keyword list of options. Options solar_elevation represents the type of sunrise required. The default is :geometric which equates to a solar elevation of 90°. In this case the calulation also accounts for refraction and elevation to return a result which accords with the eyes perception. Other solar elevations are: :civil representing a solar elevation of 96.0°. At this point the sun is just below the horizon so there is generally enough natural light to carry out most outdoor activities. :nautical representing a solar elevation of 102.0° This is the point at which the horizon is just barely visible and the moon and stars can still be used for navigation. :astronomical representing a solar elevation of 108.0°. This is the point beyond which astronomical observation becomes impractical. Any floating point number representing the desired solar elevation. :time_zone is the time zone to in which the sunrise is requested. The default is :default in which the sunrise time is reported in the time zone of the requested location. Any other time zone name supported by the option :time_zone_database is acceptabe. :time_zone_database represents the module that implements the Calendar.TimeZoneDatabase behaviour. The default is Tzdata.TimeZoneDatabase . Returns a DateTime.t representing the time of sunrise in the requested timzone at the requested location or {:error, :time_zone_not_found} if the requested time zone is unknown {:error, :no_time} if for the requested date and location there is no sunrise. This can occur at very high latitudes during summer and winter. Examples # Sunrise in Sydney, Australia Astro . sunrise ( { 151.20666584 , - 33.8559799094 } , ~D[2019-12-04] ) { :ok , # DateTime &lt; 2019 - 12 - 04 05 : 37 : 00.000000 + 11 : 00 AEDT Australia / Sydney &gt; } # Sunrise in Alert, Nanavut, Canada Astro . sunrise ( { - 62.3481 , 82.5018 } , ~D[2019-12-04] ) { :error , :no_time }","ref":"Astro.html#sunrise/3","title":"Astro.sunrise/3","type":"function"},{"doc":"Calculates the sunset for a given location and date. Sunset is the moment when the upper limb of the sun disappears below the horizon in the evening. Arguments location is the latitude, longitude and optionally elevation for the desired sunrise time. It can be expressed as: {lng, lat} - a tuple with longitude and latitude as floating point numbers. Note the order of the arguments. a Geo.Point.t struct to represent a location without elevation a Geo.PointZ.t struct to represent a location and elevation date is a t:Date , t:NaiveDateTime or t:DateTime to indicate the date of the year in which the sunset time is required. options is a keyword list of options. Options solar_elevation represents the type of sunset required. The default is :geometric which equates to a solar elevation of 90°. In this case the calulation also accounts for refraction and elevation to return a result which accords with the eyes perception. Other solar elevations are: :civil representing a solar elevation of 96.0°. At this point the sun is just below the horizon so there is generally enough natural light to carry out most outdoor activities. :nautical representing a solar elevation of 102.0° This is the point at which the horizon is just barely visible and the moon and stars can still be used for navigation. :astronomical representing a solar elevation of 108.0°. This is the point beyond which astronomical observation becomes impractical. Any floating point number representing the desired solar elevation. :time_zone is the time zone to in which the sunset is requested. The default is :default in which the sunset time is reported in the time zone of the requested location. Any other time zone name supported by the option :time_zone_database is acceptabe. :time_zone_database represents the module that implements the Calendar.TimeZoneDatabase behaviour. The default is Tzdata.TimeZoneDatabase . Returns a t:DateTime representing the time of sunset in the requested time zone at the requested location or {:error, :time_zone_not_found} if the requested time zone is unknown {:error, :no_time} if for the requested date and location there is no sunset. This can occur at very high latitudes during summer and winter. Examples # Sunset in Sydney, Australia Astro . sunset ( { 151.20666584 , - 33.8559799094 } , ~D[2019-12-04] ) { :ok , # DateTime &lt; 2019 - 12 - 04 19 : 53 : 00.000000 + 11 : 00 AEDT Australia / Sydney &gt; } # Sunset in Alert, Nanavut, Canada Astro . sunset ( { - 62.3481 , 82.5018 } , ~D[2019-12-04] ) { :error , :no_time }","ref":"Astro.html#sunset/3","title":"Astro.sunset/3","type":"function"},{"doc":"","ref":"Astro.html#t:altitude/0","title":"Astro.altitude/0","type":"type"},{"doc":"","ref":"Astro.html#t:angle/0","title":"Astro.angle/0","type":"type"},{"doc":"","ref":"Astro.html#t:date/0","title":"Astro.date/0","type":"type"},{"doc":"","ref":"Astro.html#t:degrees/0","title":"Astro.degrees/0","type":"type"},{"doc":"","ref":"Astro.html#t:latitude/0","title":"Astro.latitude/0","type":"type"},{"doc":"","ref":"Astro.html#t:location/0","title":"Astro.location/0","type":"type"},{"doc":"","ref":"Astro.html#t:longitude/0","title":"Astro.longitude/0","type":"type"},{"doc":"","ref":"Astro.html#t:meters/0","title":"Astro.meters/0","type":"type"},{"doc":"","ref":"Astro.html#t:options/0","title":"Astro.options/0","type":"type"},{"doc":"","ref":"Astro.html#t:phase/0","title":"Astro.phase/0","type":"type"},{"doc":"Constants and astronomical calculations related to the earth.","ref":"Astro.Earth.html","title":"Astro.Earth","type":"module"},{"doc":"Adjusts the solar elevation to be the apparent angle at sunrise if the requested angle is :geometric (or 90°) Arguments solar_elevation is the requested solar elevation in degress. It will be 90° for sunrise and sunset. elevation is elevation in meters Returns The solar elevation angle adjusted for refraction, elevation and solar radius.","ref":"Astro.Earth.html#adjusted_solar_elevation/2","title":"Astro.Earth.adjusted_solar_elevation/2","type":"function"},{"doc":"Returns the radius of the earth in kilometers","ref":"Astro.Earth.html#earth_radius/0","title":"Astro.Earth.earth_radius/0","type":"function"},{"doc":"Adjusts the solar elevation to account for the elevation of the requested location Arguments elevation is elevation in meters Returns The solar elevation angle adjusted for the elevation","ref":"Astro.Earth.html#elevation_adjustment/1","title":"Astro.Earth.elevation_adjustment/1","type":"function"},{"doc":"","ref":"Astro.Earth.html#nutation/1","title":"Astro.Earth.nutation/1","type":"function"},{"doc":"Returns the obliquity of the earth","ref":"Astro.Earth.html#obliquity/0","title":"Astro.Earth.obliquity/0","type":"function"},{"doc":"Returns an estimate of the effect of refraction applied to the calculation of sunrise and sunset times. Sunrise actually occurs before the sun truly reaches the horizon because earth's atmosphere refracts the Sun's image. At the horizon, the average amount of refraction is 34 arcminutes, though this amount varies based on atmospheric conditions. This effect is especially powerful for objects that appear close to the horizon, such as the rising or setting sun, because the light rays enter the earth's atmosphere at a particularly shallow angle. Because of refraction, the sun may be seen for several minutes before it actually rises in the morning and after it sets in the evening.","ref":"Astro.Earth.html#refraction/0","title":"Astro.Earth.refraction/0","type":"function"},{"doc":"Returns the suns apparent radius at sunrise/sunset. Unlike most other solar measurements, sunrise occurs when the Sun's upper limb, rather than its center, appears to cross the horizon. The apparent radius of the Sun at the horizon is 16 arcminutes.","ref":"Astro.Earth.html#solar_radius/0","title":"Astro.Earth.solar_radius/0","type":"function"},{"doc":"","ref":"Astro.Guards.html","title":"Astro.Guards","type":"module"},{"doc":"","ref":"Astro.Guards.html#datetime/0","title":"Astro.Guards.datetime/0","type":"function"},{"doc":"","ref":"Astro.Guards.html#is_alt/1","title":"Astro.Guards.is_alt/1","type":"macro"},{"doc":"","ref":"Astro.Guards.html#is_lat/1","title":"Astro.Guards.is_lat/1","type":"macro"},{"doc":"","ref":"Astro.Guards.html#is_lng/1","title":"Astro.Guards.is_lng/1","type":"macro"},{"doc":"Calulates lunar phases. Each of the phases of the Moon is defined by the angle between the Moon and Sun in the sky. When the Moon is in between the Earth and the Sun, so that there is nearly a zero degree separation, we see a New Moon. Because the orbit of the Moon is tilted in relation to the Earth’s orbit around the Sun, a New Moon can still be as much as 5.2 degrees away from the Sun, thus why there isn't a solar eclipse every month. A crescent moon is 45 degrees from the Sun, a quarter moon is 90 degrees from the Sun, a gibbous moon is 135 degrees from the Sun, and the Full Moon is 180 degrees away from the Sun.","ref":"Astro.Lunar.html","title":"Astro.Lunar","type":"module"},{"doc":"Returns the date time of a given lunar phase at or after a given date time or date. Arguments a moment which is a float number of days since 0000-01-01 phase is the required lunar phase expressed as a float number of degrees between 0 and 3660 Returns a t:Time.moment() which is a float number of days since 0000-01-01 Example iex&gt; Astro.Lunar . date_time_lunar_phase_at_or_after ( 738368 , Astro.Lunar . full_moon ( ) ) 738389.5007195254","ref":"Astro.Lunar.html#date_time_lunar_phase_at_or_after/2","title":"Astro.Lunar.date_time_lunar_phase_at_or_after/2","type":"function"},{"doc":"Returns the date time of a given lunar phase at or before a given moment. Arguments a t:Time.moment() which is a float number of days since 0000-01-01 phase is the required lunar phase expressed as a float number of degrees between 0.0 and 360.0 Returns a t:Time.moment() which is a float number of days since 0000-01-01 Example iex&gt; Astro.Lunar . date_time_lunar_phase_at_or_before ( 738368 , Astro.Lunar . new_moon ( ) ) 738346.0524695957","ref":"Astro.Lunar.html#date_time_lunar_phase_at_or_before/2","title":"Astro.Lunar.date_time_lunar_phase_at_or_before/2","type":"function"},{"doc":"Returns the date time of the new moon at or after a given date or date time. Arguments a t:Time.moment() which is a float number of days since 0000-01-01 Returns a t:Time.moment() which is a float number of days since 0000-01-01 Example iex&gt; Astro.Lunar . date_time_new_moon_at_or_after 738390 738405.0352292997","ref":"Astro.Lunar.html#date_time_new_moon_at_or_after/1","title":"Astro.Lunar.date_time_new_moon_at_or_after/1","type":"function"},{"doc":"Returns the date time of the new moon before a given moment. Arguments a t:Time.moment() which is a float number of days since 0000-01-01 Returns a t:Time.moment() which is a float number of days since 0000-01-01 Example iex&gt; Astro.Lunar . date_time_new_moon_before 738390 738375.5757777032","ref":"Astro.Lunar.html#date_time_new_moon_before/1","title":"Astro.Lunar.date_time_new_moon_before/1","type":"function"},{"doc":"Returns the first quarter lunar phase expressed as a float number of degrees.","ref":"Astro.Lunar.html#first_quarter/0","title":"Astro.Lunar.first_quarter/0","type":"function"},{"doc":"Returns the full moon lunar phase expressed as a float number of degrees.","ref":"Astro.Lunar.html#full_moon/0","title":"Astro.Lunar.full_moon/0","type":"function"},{"doc":"Returns the fractional illumination of the moon at a given time as a fraction between 0.0 and 1.0.","ref":"Astro.Lunar.html#illuminated_fraction_of_moon/1","title":"Astro.Lunar.illuminated_fraction_of_moon/1","type":"function"},{"doc":"Returns the last quarter lunar phase expressed as a float number of degrees.","ref":"Astro.Lunar.html#last_quarter/0","title":"Astro.Lunar.last_quarter/0","type":"function"},{"doc":"","ref":"Astro.Lunar.html#lunar_altitude/2","title":"Astro.Lunar.lunar_altitude/2","type":"function"},{"doc":"","ref":"Astro.Lunar.html#lunar_distance/1","title":"Astro.Lunar.lunar_distance/1","type":"function"},{"doc":"","ref":"Astro.Lunar.html#lunar_latitude/1","title":"Astro.Lunar.lunar_latitude/1","type":"function"},{"doc":"","ref":"Astro.Lunar.html#lunar_parallax/2","title":"Astro.Lunar.lunar_parallax/2","type":"function"},{"doc":"Returns the lunar phase as a float number of degrees at a given moment. Arguments a t:Time.moment() which is a float number of days since 0000-01-01 Returns the lunar phase as a float number of degrees. Example iex&gt; Astro.Lunar . lunar_phase_at 738389.5007195644 180.00001498208536 iex&gt; Astro.Lunar . lunar_phase_at 738346.0544609067 0.021567106773019873","ref":"Astro.Lunar.html#lunar_phase_at/1","title":"Astro.Lunar.lunar_phase_at/1","type":"function"},{"doc":"","ref":"Astro.Lunar.html#lunar_position/1","title":"Astro.Lunar.lunar_position/1","type":"function"},{"doc":"Returns the new moon lunar phase expressed as a float number of degrees.","ref":"Astro.Lunar.html#new_moon/0","title":"Astro.Lunar.new_moon/0","type":"function"},{"doc":"","ref":"Astro.Lunar.html#topocentric_lunar_altitude/2","title":"Astro.Lunar.topocentric_lunar_altitude/2","type":"function"},{"doc":"Implements sunrise and sunset according to the US NOAA algorithm which is based upon Astronomical Algorithms by Jean Meeus.","ref":"Astro.Solar.html","title":"Astro.Solar","type":"module"},{"doc":"Returns the unitness earth orbit eccentricity Arguments julian_centuries is the any moment in time expressed as julian centuries Returns a unitless value of eccentricity as a float . A value of 0 is a circular orbit, values between 0 and 1 form an elliptic orbit, 1 is a parabolic escape orbit, and greater than 1 is a hyperbola Notes The orbital eccentricity of earth - and any astronomical object - is a dimensionless parameter that determines the amount by which its orbit around another body deviates from a perfect circle. The term derives its name from the parameters of conic sections, as every Kepler orbit is a conic section.","ref":"Astro.Solar.html#earth_orbit_eccentricity/1","title":"Astro.Solar.earth_orbit_eccentricity/1","type":"function"},{"doc":"Returns the euation of time in minutes Arguments julian_centuries is the any moment in time expressed as julian centuries Returns The discrepency between apparent time and mean solar time in minutes as a float . Notes The equation of time describes the discrepancy between two kinds of solar time. The word equation is used in the medieval sense of &quot;reconcile a difference&quot;. The two times that differ are the apparent solar time, which directly tracks the diurnal motion of the Sun, and mean solar time, which tracks a theoretical mean Sun with uniform motion. Apparent solar time can be obtained by measurement of the current position (hour angle) of the Sun, as indicated (with limited accuracy) by a sundial. Mean solar time, for the same place, would be the time indicated by a steady clock set so that over the year its differences from apparent solar time would have a mean of zero. During a year the equation of time varies as shown on the graph; its change from one year to the next is slight. Apparent time, and the sundial, can be ahead (fast) by as much as 16 min 33 s (around 3 November), or behind (slow) by as much as 14 min 6 s (around 11 February). The equation of time has zeros near 15 April, 13 June, 1 September, and 25 December. Ignoring very slow changes in the Earth's orbit and rotation, these events are repeated at the same times every tropical year. However, due to the non-integral number of days in a year, these dates can vary by a day or so from year to year. The graph of the equation of time is closely approximated by the sum of two sine curves, one with a period of a year and one with a period of half a year. The curves reflect two astronomical effects, each causing a different non-uniformity in the apparent daily motion of the Sun relative to the stars: the obliquity of the ecliptic (the plane of the Earth's annual orbital motion around the Sun), which is inclined by about 23.44 degrees relative to the plane of the Earth's equator; and the eccentricity of the Earth's orbit around the Sun, which is about 0.0167. The equation of time is constant only for a planet with zero axial tilt and zero orbital eccentricity. On Mars the difference between sundial time and clock time can be as much as 50 minutes, due to the considerably greater eccentricity of its orbit. The planet Uranus, which has an extremely large axial tilt, has an equation of time that makes its days start and finish several hours earlier or later depending on where it is in its orbit.","ref":"Astro.Solar.html#equation_of_time/1","title":"Astro.Solar.equation_of_time/1","type":"function"},{"doc":"Returns the datetime of an equinox or solstice","ref":"Astro.Solar.html#equinox_and_solstice/2","title":"Astro.Solar.equinox_and_solstice/2","type":"function"},{"doc":"Return approximate moment at or before tee when solar longitude just exceeded lam degrees.","ref":"Astro.Solar.html#estimate_prior_solar_longitude/2","title":"Astro.Solar.estimate_prior_solar_longitude/2","type":"function"},{"doc":"Returns the mean obliquity of the ecliptic in degrees Arguments julian_centuries is the any moment in time expressed as julian centuries Returns the mean obliquity of the ecliptic in degrees as a float Notes Obliquity, also known as tilt, is the angle between the rotation access of the earth from the orbital plane of the earth around the sun. Earth's obliquity angle is measured from the imaginary line that runs perpendicular to another imaginary line; Earth's ecliptic plane or orbital plane . At the moment, Earth's obliquity is about 23.4 degrees and decreasing. We say 'at the moment' because the obliquity changes over time, although very, very slowly.","ref":"Astro.Solar.html#mean_obliquity_of_ecliptic/1","title":"Astro.Solar.mean_obliquity_of_ecliptic/1","type":"function"},{"doc":"Returns the obliquity correction in degrees Arguments julian_centuries is the any moment in time expressed as julian centuries Returns the obliquity correction in degrees as a float","ref":"Astro.Solar.html#obliquity_correction/1","title":"Astro.Solar.obliquity_correction/1","type":"function"},{"doc":"Returns the solar declination in degrees Arguments julian_centuries is the any moment in time expressed as julian centuries Returns the solar declination in degrees as a float Notes The solar declination is the angle between the direction of the center of the solar disk measured from Earth's center and the equatorial plane","ref":"Astro.Solar.html#solar_declination/1","title":"Astro.Solar.solar_declination/1","type":"function"},{"doc":"","ref":"Astro.Solar.html#solar_distance/1","title":"Astro.Solar.solar_distance/1","type":"function"},{"doc":"","ref":"Astro.Solar.html#solar_longitude/1","title":"Astro.Solar.solar_longitude/1","type":"function"},{"doc":"Return the moment UT of the first time at or after moment, tee, when the solar longitude will be lamda degrees.","ref":"Astro.Solar.html#solar_longitude_after/2","title":"Astro.Solar.solar_longitude_after/2","type":"function"},{"doc":"Returns solar noon as minutes since midnight UTC Arguments julian_centuries is the any moment in time expressed as julian centuries longitude is the longitude in degrees of the location from which solar noon is to be measured Returns solar noon as a float number of minutes since midnight UTC Notes Solar noon is the moment when the Sun passes a location's meridian and reaches its highest position in the sky. In most cases, it doesn't happen at 12 o'clock. At solar noon, the Sun reaches its highest position in the sky as it passes the local meridian.","ref":"Astro.Solar.html#solar_noon_utc/2","title":"Astro.Solar.solar_noon_utc/2","type":"function"},{"doc":"","ref":"Astro.Solar.html#solar_position/1","title":"Astro.Solar.solar_position/1","type":"function"},{"doc":"Returns the suns apparent longitude in degrees Arguments julian_centuries is the any moment in time expressed as julian centuries Returns equation of the center in degrees as a float Notes The apparent longitude is the sun's celestial longitude corrected for aberration and nutation as opposed to mean longitude An equinox is the instant when the Sun's apparent geocentric longitude is 0° (northward equinox) or 180° (southward equinox).","ref":"Astro.Solar.html#sun_apparent_longitude/1","title":"Astro.Solar.sun_apparent_longitude/1","type":"function"},{"doc":"Return the sun's equation of the center in degrees Arguments julian_centuries is the any moment in time expressed as julian centuries Returns equation of the center in degrees as a float Notes In two-body, Keplerian orbital mechanics, the equation of the center is the angular difference between the actual position of a body in its elliptical orbit and the position it would occupy if its motion were uniform, in a circular orbit of the same period. It is defined as the difference true anomaly, ν, minus mean anomaly, M, and is typically expressed a function of mean anomaly, M, and orbital eccentricity, e.","ref":"Astro.Solar.html#sun_equation_of_center/1","title":"Astro.Solar.sun_equation_of_center/1","type":"function"},{"doc":"Returns the suns geometric mean anomoly in degrees Arguments julian_centuries is the any moment in time expressed as julian centuries Returns the mean anomoly in degrees as a float Notes In celestial mechanics, the mean anomaly is the fraction of an elliptical orbit's period that has elapsed since the orbiting body passed periapsis, expressed as an angle which can be used in calculating the position of that body in the classical two-body problem. It is the angular distance from the pericenter which a fictitious body would have if it moved in a circular orbit, with constant speed, in the same orbital period as the actual body in its elliptical orbit","ref":"Astro.Solar.html#sun_geometric_mean_anomaly/1","title":"Astro.Solar.sun_geometric_mean_anomaly/1","type":"function"},{"doc":"Returns the suns geometric mean longitude in degrees Arguments julian_centuries is the any moment in time expressed as julian centuries Returns the mean solar longitude in degrees as a float Notes Mean longitude, like mean anomaly, does not measure an angle between any physical objects. It is simply a convenient uniform measure of how far around its orbit a body has progressed since passing the reference direction. While mean longitude measures a mean position and assumes constant speed, true longitude measures the actual longitude and assumes the body has moved with its actual speed, which varies around its elliptical orbit. The difference between the two is known as the equation of the center.","ref":"Astro.Solar.html#sun_geometric_mean_longitude/1","title":"Astro.Solar.sun_geometric_mean_longitude/1","type":"function"},{"doc":"Returns the suns true longitude in degrees Arguments julian_centuries is the any moment in time expressed as julian centuries Returns the suns true longitude in degrees as a float Notes In celestial mechanics true longitude is the ecliptic longitude at which an orbiting body could actually be found if its inclination were zero. Together with the inclination and the ascending node, the true longitude can tell us the precise direction from the central object at which the body would be located at a particular time.","ref":"Astro.Solar.html#sun_true_longitude/1","title":"Astro.Solar.sun_true_longitude/1","type":"function"},{"doc":"Returns the UTC time of sun's position for a given location as a float time-of-day. Arguments date is a DateTime.t() in the UTC time zone location is any Geo.PointZ.t() location solar_elevation is the required solar elevation in degrees (90 degrees for sunrise and sunset) mode is :sunrise or :sunset Returns {:ok, moment} where moment is float representing the number of hours after midnight for sunrise or sunset or {:error, :no_time} if there is no sunrise/sunset for the given date at the given location. This can occur for very high latitudes in winter and summer. Notes This implementation is based on equations from Astronomical Algorithms , by Jean Meeus. The sunrise and sunset results are theoretically accurate to within a minute for locations between +/- 72° latitude, and within 10 minutes outside of those latitudes. However, due to variations in atmospheric composition, temperature, pressure and conditions, observed values may vary from calculations.","ref":"Astro.Solar.html#utc_sun_position/4","title":"Astro.Solar.utc_sun_position/4","type":"function"},{"doc":"Provides a supervision tree under which the required TzWorld backend server can be started.","ref":"Astro.Supervisor.html","title":"Astro.Supervisor","type":"module"},{"doc":"Starts a TzWorld backend module that manages the time zone data required for Astro to operate. The backend process is started under a supervisor called Astro.Supervisor.","ref":"Astro.Supervisor.html#start/2","title":"Astro.Supervisor.start/2","type":"function"},{"doc":"Calculations converting between geometry and time All public functions use degrees as their input parameters Time is a fraction of a day after UTC","ref":"Astro.Time.html","title":"Astro.Time","type":"module"},{"doc":"See Astro.Time.julian_day_from_date/1 .","ref":"Astro.Time.html#ajd/1","title":"Astro.Time.ajd/1","type":"function"},{"doc":"Adds the requested minutes to a date returning a datetime in the UTC time zone Arguments minutes is a float number of minutes since midnight date is any date in the Gregorian calendar Returns a datetime in the UTC time zone","ref":"Astro.Time.html#datetime_from_date_and_minutes/2","title":"Astro.Time.datetime_from_date_and_minutes/2","type":"function"},{"doc":"Returns the datetime for a given Julian day Arguments julian_day is any astronomical Julian day such as returned from Astro.Time.julian_day_from_date/1 Returns a DateTime.t in the UTC time zone Example iex&gt; Astro.Time . datetime_from_julian_days 2458822.5 { :ok , ~U[2019-12-05 00:00:00Z] }","ref":"Astro.Time.html#datetime_from_julian_days/1","title":"Astro.Time.datetime_from_julian_days/1","type":"function"},{"doc":"","ref":"Astro.Time.html#days_from_minutes/1","title":"Astro.Time.days_from_minutes/1","type":"function"},{"doc":"Returns the dynamical time for a given universal time. Dynamical time is the time-scale that is used in calculating orbital motions within the Solar System. The underlying physical law governing such motions is the law of gravitation.","ref":"Astro.Time.html#dynamical_from_universal/1","title":"Astro.Time.dynamical_from_universal/1","type":"function"},{"doc":"","ref":"Astro.Time.html#ephemeris_correction/1","title":"Astro.Time.ephemeris_correction/1","type":"function"},{"doc":"","ref":"Astro.Time.html#hours_per_day/0","title":"Astro.Time.hours_per_day/0","type":"function"},{"doc":"Converts a number of hourse into days. Arguments Returns Examples","ref":"Astro.Time.html#hours_to_days/1","title":"Astro.Time.hours_to_days/1","type":"function"},{"doc":"Converts a float number of hours since midnight into {hours, minutes, seconds} . Arguments time_of_day is a float number of hours since midnight Returns A {hour, minute, second} tuple. Examples iex&gt; Astro.Time.hours_to_hms 0.0 {0, 0, 0} iex&gt; Astro.Time.hours_to_hms 23.999 {23, 59, 56} iex&gt; Astro.Time.hours_to_hms 15.456 {15, 27, 21}","ref":"Astro.Time.html#hours_to_hms/1","title":"Astro.Time.hours_to_hms/1","type":"function"},{"doc":"","ref":"Astro.Time.html#hr/1","title":"Astro.Time.hr/1","type":"function"},{"doc":"Returns the day number for January 1st, 2000","ref":"Astro.Time.html#j2000/0","title":"Astro.Time.j2000/0","type":"function"},{"doc":"Returns the Julian centuries for a given Julian day Arguments julian_day is any astronomical Julian day such as returned from Astro.Time.julian_day_from_date/1 Returns the astronomical Julian century as a float","ref":"Astro.Time.html#julian_centuries_from_julian_day/1","title":"Astro.Time.julian_centuries_from_julian_day/1","type":"function"},{"doc":"","ref":"Astro.Time.html#julian_centuries_from_moment/1","title":"Astro.Time.julian_centuries_from_moment/1","type":"function"},{"doc":"Returns the astronomical Julian day for a given date Arguments date is any Calendar.date Returns the astronomical Julian day as a float Example iex&gt; Astro.Time.julian_day_from_date ~D[2019-12-05] 2458822.5","ref":"Astro.Time.html#julian_day_from_date/1","title":"Astro.Time.julian_day_from_date/1","type":"function"},{"doc":"Returns the Julian day for a given Julian century Arguments julian_century is any astronomical Julian century such as returned from Astro.Time.julian_centuries_from_julian_day/1 Returns the astronomical Julian day as a float","ref":"Astro.Time.html#julian_day_from_julian_centuries/1","title":"Astro.Time.julian_day_from_julian_centuries/1","type":"function"},{"doc":"Returns the local time from the universal time at a given location. Locale time is UTC time plus the number of hours offset calculated from the longitude of a location. This is different to standard time which is UTC time adjusted for a specific time zone name.","ref":"Astro.Time.html#local_from_universal/2","title":"Astro.Time.local_from_universal/2","type":"function"},{"doc":"","ref":"Astro.Time.html#mean_synodic_month/0","title":"Astro.Time.mean_synodic_month/0","type":"function"},{"doc":"","ref":"Astro.Time.html#mean_tropical_year/0","title":"Astro.Time.mean_tropical_year/0","type":"function"},{"doc":"","ref":"Astro.Time.html#minutes_per_day/0","title":"Astro.Time.minutes_per_day/0","type":"function"},{"doc":"","ref":"Astro.Time.html#minutes_per_hour/0","title":"Astro.Time.minutes_per_hour/0","type":"function"},{"doc":"Returns the modified Julian day for a date Arguments date is any Calendar.date Returns the modified Julian day as a float Notes A modified version of the Julian date denoted MJD is obtained by subtracting 2,400,000.5 days from the Julian date JD, The MJD therefore gives the number of days since midnight on November 17, 1858. This date corresponds to 2400000.5 days after day 0 of the Julian calendar.","ref":"Astro.Time.html#mjd/1","title":"Astro.Time.mjd/1","type":"function"},{"doc":"Converts a float number of hours since midnight to a DateTime.t() Arguments time_of_day is a float number of hours since midnight date is any Calendar.date() Returns A DateTime.t() combining the date and time_of_day in the UTC timezone.","ref":"Astro.Time.html#moment_to_datetime/2","title":"Astro.Time.moment_to_datetime/2","type":"function"},{"doc":"Returns the offset in float days for a given moment and time zone. Example # Returns a 1 hour offset as a fraction of day iex&gt; t = Date . to_gregorian_days ( ~D[2021-08-01] ) iex&gt; Astro.Time . offset_for_zone t , &quot;Europe/London&quot; 0.041666666666666664","ref":"Astro.Time.html#offset_for_zone/2","title":"Astro.Time.offset_for_zone/2","type":"function"},{"doc":"","ref":"Astro.Time.html#offset_from_location/2","title":"Astro.Time.offset_from_location/2","type":"function"},{"doc":"Returns the zone difference in hours between a given location and UTC.","ref":"Astro.Time.html#offset_from_longitude/1","title":"Astro.Time.offset_from_longitude/1","type":"function"},{"doc":"","ref":"Astro.Time.html#seconds_per_hour/0","title":"Astro.Time.seconds_per_hour/0","type":"function"},{"doc":"","ref":"Astro.Time.html#seconds_per_minute/0","title":"Astro.Time.seconds_per_minute/0","type":"function"},{"doc":"Converts a number of seconds since midnight into {hours, minutes, seconds} . Arguments time_of_day is a number of seconds Returns A {hour, minute, second} tuple. Examples iex&gt; Astro.Time.seconds_to_hms 0.0 {0, 0, 0} iex&gt; Astro.Time.seconds_to_hms 3214 {0, 53, 34} iex&gt; Astro.Time.seconds_to_hms 10_000 {2, 46, 39}","ref":"Astro.Time.html#seconds_to_hms/1","title":"Astro.Time.seconds_to_hms/1","type":"function"},{"doc":"","ref":"Astro.Time.html#sidereal_from_moment/1","title":"Astro.Time.sidereal_from_moment/1","type":"function"},{"doc":"Returns the standard time for a universal time in a given time zone.","ref":"Astro.Time.html#standard_from_universal/2","title":"Astro.Time.standard_from_universal/2","type":"function"},{"doc":"Returns the universal (UTC) time for a given dynamical time. Coordinated Universal Time or UTC is the primary time standard by which the world regulates clocks and time. It is within about 1 second of mean solar time at 0° longitude and is not adjusted for daylight saving time. It is effectively a successor to Greenwich Mean Time (GMT).","ref":"Astro.Time.html#universal_from_dynamical/1","title":"Astro.Time.universal_from_dynamical/1","type":"function"},{"doc":"Returns the universal time (UTC) from the local time at a given location. Locale time is UTC time plus the number of hours offset calculated from the longitude of a location. This is different to standard time which is UTC time adjusted for a specific time zone name.","ref":"Astro.Time.html#universal_from_local/2","title":"Astro.Time.universal_from_local/2","type":"function"},{"doc":"Returns the universal (UTC) time for a standard time in a given time zone.","ref":"Astro.Time.html#universal_from_standard/2","title":"Astro.Time.universal_from_standard/2","type":"function"},{"doc":"Converts a terrestrial datetime to a UTC datetime Arguments datetime is any UTC datetime which is considered to be a Terrestrial Time. Returns A UTC datetime adjusted for the difference between Terrestrial Time and UTC time Notes Terrestrial Time (TT) was introduced by the IAU in 1979 as the coordinate time scale for an observer on the surface of Earth. It takes into account relativistic effects and is based on International Atomic Time (TAI), which is a high-precision standard using several hundred atomic clocks worldwide. As such, TD is the atomic time equivalent to its predecessor Ephemeris Time (ET) and is used in the theories of motion for bodies in the solar system. To ensure continuity with ET, TD was defined to match ET for the date 1977 Jan 01. In 1991, the IAU refined the definition of TT to make it more precise. It was also renamed Terrestrial Time (TT) from the earlier Terrestrial Dynamical Time (TDT).","ref":"Astro.Time.html#utc_datetime_from_terrestrial_datetime/1","title":"Astro.Time.utc_datetime_from_terrestrial_datetime/1","type":"function"},{"doc":"","ref":"Astro.Time.html#t:hours/0","title":"Astro.Time.hours/0","type":"type"},{"doc":"The current Julian epoch is defined to have been noon on January 1, 2000. This epoch is denoted J2000 and has the exact Julian day number 2,451,545.0. Since there are 365.25 days in a Julian year, a Julian century has 36,525 days.","ref":"Astro.Time.html#t:julian_centuries/0","title":"Astro.Time.julian_centuries/0","type":"type"},{"doc":"A moment is a floating point representations of the fraction of a day.","ref":"Astro.Time.html#t:moment/0","title":"Astro.Time.moment/0","type":"type"},{"doc":"","ref":"Astro.Time.html#t:season/0","title":"Astro.Time.season/0","type":"type"},{"doc":"A time is a floating point number of days since 0000-01-01 including the fractional part of a day.","ref":"Astro.Time.html#t:time/0","title":"Astro.Time.time/0","type":"type"},{"doc":"","ref":"Astro.Time.html#t:zone_name/0","title":"Astro.Time.zone_name/0","type":"type"},{"doc":"Astro Astro is a library to provide basic astromonomical functions with a focus on functions that support solar, lunar and lunisolar calendars such as the Chinese, Hebrew and Persian calendars.","ref":"readme.html","title":"Astro","type":"extras"},{"doc":"NOTE: It's important to install and configure Astro correctly before use. See the installation notes below. The primary functions are: Astro.sunrise/3 Astro.sunset/3 Astro.solstice/2 Astro.equinox/2 Astro.hours_of_daylight/2 Examples # Sunrise in Sydney on December 4th iex&gt; Astro . sunrise ( { 151.20666584 , - 33.8559799094 } , ~D[2019-12-04] ) { :ok , # DateTime &lt; 2019 - 12 - 04 05 : 37 : 00.000000 + 11 : 00 AEDT Australia / Sydney &gt; } # Sunset in Sydney on December 4th iex&gt; Astro . sunset ( { 151.20666584 , - 33.8559799094 } , ~D[2019-12-04] ) { :ok , # DateTime &lt; 2019 - 12 - 04 19 : 53 : 00.000000 + 11 : 00 AEDT Australia / Sydney &gt; } # Sunset in the town of Alert in Nunavut, Canada # ...doesn&#39;t exist since there is no sunset in summer iex&gt; Astro . sunset ( { - 62.3481 , 82.5018 } , ~D[2019-07-01] ) { :error , :no_time } # ...or sunrise in winter iex&gt; Astro . sunrise ( { - 62.3481 , 82.5018 } , ~D[2019-12-04] ) { :error , :no_time } # Hours of daylight on December 7th in Sydney iex&gt; Astro . hours_of_daylight { 151.20666584 , - 33.8559799094 } , ~D[2019-12-07] { :ok , ~T[14:18:45] } # No sunset in summer at high latitudes iex&gt; Astro . hours_of_daylight { - 62.3481 , 82.5018 } , ~D[2019-06-07] { :ok , ~T[23:59:59] } # No sunrise in winter at high latitudes iex&gt; Astro . hours_of_daylight { - 62.3481 , 82.5018 } , ~D[2019-12-07] { :ok , ~T[00:00:00] } # Calculate solstices for 2019 iex&gt; Astro . solstice 2019 , :december { :ok , ~U[2019-12-22 04:18:57Z] } iex&gt; Astro . solstice 2019 , :june { :ok , ~U[2019-06-21 15:53:45Z] } # Calculate equinoxes for 2019 iex&gt; Astro . equinox 2019 , :march { :ok , ~U[2019-03-20 21:58:06Z] } iex&gt; Astro . equinox 2019 , :september { :ok , ~U[2019-09-23 07:49:30Z] } Specifying a location The desired location of sunrise or sunset can be specified as either: a tuple of longitude and latitude (note the order) such as {-62.3481, 82.5018} a tuple of longitude, latitude and elevation (note the order) such as {-62.3481, 82.5018, 0} . a Geo.Point.t struct a Geo.PointZ.t struct Location units and direction For this implementation, the latitude and longitude of the functions in Astro are specified as follows: Longitude is + for eastern longitudes and - for western longitudes and specified in degrees Latitude is + for northern latitudes and - for southern latitudes and specified in degrees Elevation is specified in meters","ref":"readme.html#usage","title":"Astro - Usage","type":"extras"},{"doc":"Thanks to @pinnymz for the ruby-zmanim gem which has a well structured ruby implementation of sunrise / sunset and some core astronomical algorithms. Eventually all roads lead to the canonical book on the subject by Jean Meeus: Astronomical Algorithms For the intersection of calendars and astronomy, Calendrical Calculations by Nachum Dershowitz and Edward M. Reingold remains the standard reference. On the web, timeanddate.com is a great reference. The sunrise/sunset calculations in this library are tested to return times within 1 minute of timeanddate.com results. Wikipedia for content to help describe the understanding behind some of the functions","ref":"readme.html#references","title":"Astro - References","type":"extras"},{"doc":"Configure Astro Astro can be installed by adding astro to your list of dependencies in mix.exs : def deps do [ { :astro , &quot;~&gt; 0.7.0&quot; } ] end Install TzWorld Data Then get dependencies and install the data required to determine a time zone from a location which is used by the dependency tz_world . mix deps . get mix tz_world . update Add TzWorld to supervision tree It is also required that tz_world be added to your applications supervision tree by adding the relevant tz_world backend to it in your MyApp.Application module: defmodule MyApp.Application do use Application def start ( _type , _args ) do children = [ ... .. # See the documentation for tz_world for the # various available backends. This is the recommended # backend. TzWorld.Backend.DetsWithIndexCache ] opts = [ strategy : :one_for_one , name : Astro.Supervisor ] Supervisor . start_link ( children , opts ) end end Configure your application module Make sure that you have configured your application in mix.exs : def application do [ mod : { MyApp.Application , [ strategy : :one_for_one ] } , ... .. ] end Documentation can be found at https://hexdocs.pm/astro .","ref":"readme.html#installation","title":"Astro - Installation","type":"extras"},{"doc":"License Copyright 2018-2019 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http :/ / www . apache . org / licenses / LICENSE - 2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html","title":"License","type":"extras"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This is the changelog for Astro version 0.8.0 released on October 3rd, 2021. For older changelogs please consult the release tag on GitHub Please note that Elixir 1.11 or later is required. Enhancements Convert some identity functions to macros which improves runtime performance Add additional specs and docs to Astro.Math module","ref":"changelog.html#astro-version-0-8-0","title":"Changelog - Astro version 0.8.0","type":"extras"},{"doc":"This is the changelog for Astro version 0.7.0 released on September 10th, 2021. For older changelogs please consult the release tag on GitHub Please note that Elixir 1.11 or later is required. Bug Fixes Revert Astro back to a pure library application. The supervisor for TzWorld still needs to be started. This fix brings the code back into line with the README . Thanks to @dvic for the report. Closes #1.","ref":"changelog.html#astro-version-0-7-0","title":"Changelog - Astro version 0.7.0","type":"extras"},{"doc":"This is the changelog for Astro version 0.6.0 released on September 5th, 2021. For older changelogs please consult the release tag on GitHub Please note that Elixir 1.11 or later is required. Bug Fixes Fix Astro.Math.atan_r/2 Fix ephemeris calculation Breaking changes Change Time.date_time_{from, to}_iso_days/1 to Time.date_time_{from, to}_moment/1 Enhancements Remove dependency on ex_cldr_calendar and jason Add Astro.sun_position_at/1 Add Astro.moon_position_at/1 Add Astro.illuminated_fraction_of_moon_at/1","ref":"changelog.html#astro-version-0-6-0","title":"Changelog - Astro version 0.6.0","type":"extras"},{"doc":"This is the changelog for Astro version 0.5.0 released on August 26th, 2021. For older changelogs please consult the release tag on GitHub Please note that Elixir 1.11 or later is required. Bug Fixes Updates documentation to be clear about installation and setup requirements for tz_world Fixes test data for São Paulo now that it no longer uses DST Ensure :astro is started in test mode Enhancements This primary focus of this release is to add lunar calculations for moon phase. Adds Astro.date_time_new_moon_before/1 Adds Astro.date_time_new_moon_at_or_after/1 Adds Astro.lunar_phase_at/1 Adds Astro.date_time_lunar_phase_at_or_before/2 Adds Astro.date_time_lunar_phase_at_or_after/2","ref":"changelog.html#astro-version-0-5-0","title":"Changelog - Astro version 0.5.0","type":"extras"},{"doc":"This is the changelog for Astro version 0.4.0 released on February 16th, 2020. For older changelogs please consult the release tag on GitHub Breaking Change When no timezone is found the return is changed from {:error, :timezone_not_found} to {:error, :time_zone_not_found} to be consistent with Elixir and TzData .","ref":"changelog.html#astro-version-0-4-0","title":"Changelog - Astro version 0.4.0","type":"extras"},{"doc":"This is the changelog for Astro version 0.3.0 released on December 9th, 2019. For older changelogs please consult the release tag on GitHub Change in behaviour Seconds are no longer truncated to zero when calculating datetimes and durations Enhancements Add Astro.solar_noon/2 to return the true solar noon for a location and date Add Astro.hours_of_daylight/2 to return hours, minutes and seconds as a Time.t() representing the number of daylight hours for a give location and date Add Astro.sun_apparent_longitude/1 to return the apparent solar longitude on a given date. The result, a number of degrees between 0 and 360, can be used to determine the seasons.","ref":"changelog.html#astro-version-0-3-0","title":"Changelog - Astro version 0.3.0","type":"extras"},{"doc":"This is the changelog for Astro version 0.2.0 released on December 6th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Add Astro.equinox/2 and Astro.solstice/2 to calculate solstices and equinoxes for a year. From these can be derived the seasons. Add Astro.Time.datetime_from_julian_days/1 Add Astro.Time.utc_datetime_from_terrestrial_datetime/1","ref":"changelog.html#astro-version-0-2-0","title":"Changelog - Astro version 0.2.0","type":"extras"},{"doc":"This is the changelog for Astro version 0.1.0 released on December 5th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Initial release includes Astro.sunrise/3 and Astro.sunset/3 . See the readme for further roadmap details.","ref":"changelog.html#astro-version-0-1-0","title":"Changelog - Astro version 0.1.0","type":"extras"}]